@@ -1,17 +1,20 @@
 from fastapi import FastAPI, Response, Form
 import requests
+from typing import Optional
 import uvicorn
 from .. import api_key, BASE_URL
 
 from ..models.agent import AgentConfig
+from ..models.synthesizer import SynthesizerConfig
 from ..models.telephony import CreateInboundCall
 
-VOCODE_INBOUND_CALL_URL = f"https://{BASE_URL}/create_inbound_call"
+VOCODE_INBOUND_CALL_URL = f"https://api.vocode.dev/create_inbound_call"
 
 class InboundCallServer():
 
-    def __init__(self, agent_config: AgentConfig):
+    def __init__(self, agent_config: AgentConfig, synthesizer_config: Optional[SynthesizerConfig]):
         self.agent_config = agent_config
+        self.synthesizer_config = synthesizer_config
         self.app = FastAPI()
         self.app.post("/vocode")(self.handle_call)
 
@@ -23,6 +26,7 @@ class InboundCallServer():
             },
             json=CreateInboundCall(
                 agent_config=self.agent_config,
+                synthesizer_config=self.synthesizer_config,
                 twilio_sid=twilio_sid
             ).dict()
         )
